==> sl-cia-2.0.83.tgz: package/lib/cli.js <==
﻿var nopt = require("nopt"),
    noptTypes = require("./nopt-types.js"),
    noptUsage = require("nopt-usage"),
    path = require("path"),
    NewDiffService = require("./new-diff-service.js").NewDiffService,
    Promise = require('promise'),
    parseDependencies = require('./dependency-parser.js').parseDependencies,
    BuildDiffProcess = require("./build-diff-process.js").BuildDiffProcess,
    cfgLoader = require('./configuration-loader.js'),
    needle = require('needle'),
    readJsonSync = require('read-json-sync');


function CIA(sourceConrolProviders) {
    this.getSourceConrolProviders = function () { return sourceConrolProviders; };
}

CIA.prototype.run = function run(callback) {
    console.log('SeaLights Build agent ' + require("../package.json").version);
    nopt.typeDefs.git = noptTypes.git;
    
    var hasMissingArguments = false;
    nopt.invalidHandler = function (key, val, types) {
        hasMissingArguments = true;
        console.log('Invalid value specified for ' + key + ': ' + val);
    };
    
    var knownOpts = {
        "workspacepath" : path
        , "outputpath": path
        , "branch" : String
        , "build" : String
        , "commit" : String
        , "appname" : String
        , "config" : String
        , "scm" : "scm"
        , "help": Boolean
        , "dependency": [String, Array]
        , "dependenciesFile": path
        , "recursive": Boolean
        , "author": [String]
        , "logsUrl": String
        , "jobName": String
    },
        shortHands = {
            "h": ["--help"],
            "d": ["--dependency"],
            "r": ["--recursive"]
        },

        description = {
            "workspacepath": " Path to the workspace where the source code exists",
            "outputpath": " Path where the compiled output exists",
            "branch": " Branch name",
            "build": " Build version",
            "commit": " commit ID, as provided by the SCM (e.g. SHA1 for git, revision for SVN, changeset for TFS). May be automatically detected by the SCM.",
            "appname": " Application Name",
            //"technology": " The technology in which the project is written (more than one value may be specified)",
            "scm": " The Source Control Management used (currently only 'git' is supported)",
            "help": " Show this help page",
            "dependency": " Project dependencies. Pattern should be a semicolon-separated AppName@Branch@Build list. May be specified more than once.",
            "dependenciesFile": " A path to a json file that is in the following format: [{\"appName\":\"\",\"branch\":\"\",\"build\":\"\"},{...}]",
            "recursive": "Starts a recursive search for JARs & WARs in folder specified by the 'workspacepath' option",
            "author": "Optional. The name or email of the user that should be associated with this build. May be specified more than once.",
            "logsUrl": "Optional. The logs url of the build.",
            "jobName": "Optional. The jenkins job name that triggered the build."
        },

        defaults = {
            "help": "",
        };

    var buildArguments = nopt(knownOpts, shortHands, process.argv, 2);
    ["branch", "build", "appname"].forEach(function (key) {
        if (!buildArguments[key]) {
            console.error("Required argument '" + key + "' not specified");
            hasMissingArguments = true;
        }
    });

    var hadInvalidArguments = false;

    //workspacepath, scm must all come together or not at all
    var count = 0;
    ["workspacepath", "scm"].forEach(function (key) {
        if (buildArguments[key]) {
            count++;
        }
    });

    if (count != 0 && count != 2) {
        console.error("The 'workspacepath' and 'scm' command-line arguments must be specified together or not at all");
        hadInvalidArguments = true;
    }

    var parsedDependencies = [];
    if (buildArguments.dependency && !hadInvalidArguments) {
        try {
            parsedDependencies = parseDependencies(buildArguments.dependency);
        }
        catch (e) {
            console.error(e);
            hadInvalidArguments = true;
        }
    }
    
    if (buildArguments.dependenciesFile && !hadInvalidArguments) {
        try {
            var parsedJson = readJsonSync(buildArguments.dependenciesFile);
            if (!parsedJson || !Array.isArray(parsedJson)) {
                throw 'Invalid file structure';
            }
            
            parsedJson.forEach(function (depItem) {
                if (depItem.appName && depItem.build && depItem.branch) {
                    parsedDependencies.push({ appName: depItem.appName.toString(), branch: depItem.branch.toString(), build: depItem.build.toString() });
                } else {
                    throw 'Invalid dependency item: ' + JSON.stringify(depItem);
                }
            });

        } catch (e) {
            console.error('Error reading/parsing ' + buildArguments.dependenciesFile + ": " + e);
            hadInvalidArguments = true;
        }
    }
    
    if (hasMissingArguments || hadInvalidArguments || buildArguments.help) {
        try {
            var usage = noptUsage(knownOpts, shortHands, description, defaults);
            console.error(usage);
        } catch (e) {
            console.error(e);
        }
        callback(1);
        return;
    }

    var sourceConrolProviders = this.getSourceConrolProviders();
    var cfg = cfgLoader(buildArguments.config).then(function (cfg) {
        var diffService = new NewDiffService(cfg, needle);
            var buildDiffProcess = new BuildDiffProcess(cfg, diffService, sourceConrolProviders, parsedDependencies);
            buildDiffProcess.run(buildArguments).then(function () {
                callback(0);
        }).catch(function (err) {
            callback(1);
            });
    });
}

module.exports.CIA = CIA;

==> sl-cia-2.0.88.tgz: package/lib/cli.js <==
﻿var nopt = require("nopt"),
    noptTypes = require("./nopt-types.js"),
    noptUsage = require("nopt-usage"),
    path = require("path"),
    NewDiffService = require("./new-diff-service.js").NewDiffService,
    Promise = require('promise'),
    parseDependencies = require('./dependency-parser.js').parseDependencies,
    BuildDiffProcess = require("./build-diff-process.js").BuildDiffProcess,
    cfgLoader = require('./configuration-loader.js'),
    needle = require('needle'),
    readJsonSync = require('read-json-sync');


function CIA(sourceConrolProviders) {
    this.getSourceConrolProviders = function () { return sourceConrolProviders; };
}

CIA.prototype.run = function run(callback) {
    console.log('SeaLights Build agent ' + require("../package.json").version);
    nopt.typeDefs.git = noptTypes.git;
    
    var hasMissingArguments = false;
    nopt.invalidHandler = function (key, val, types) {
        hasMissingArguments = true;
        console.log('Invalid value specified for ' + key + ': ' + val);
    };
    
    var knownOpts = {
        "workspacepath" : path
        , "outputpath": path
        , "branch" : String
        , "build" : String
        , "commit" : String
        , "appname" : String
        , "config" : String
        , "scm" : "scm"
        , "help": Boolean
        , "dependency": [String, Array]
        , "dependenciesFile": path
        , "recursive": Boolean
        , "author": [String]
        , "logsUrl": String
        , "jobName": String
        , "usebranchcoverage": Boolean
    },
        shortHands = {
            "h": ["--help"],
            "d": ["--dependency"],
            "r": ["--recursive"]
        },

        description = {
            "workspacepath": " Path to the workspace where the source code exists",
            "outputpath": " Path where the compiled output exists",
            "branch": " Branch name",
            "build": " Build version",
            "commit": " commit ID, as provided by the SCM (e.g. SHA1 for git, revision for SVN, changeset for TFS). May be automatically detected by the SCM.",
            "appname": " Application Name",
            //"technology": " The technology in which the project is written (more than one value may be specified)",
            "scm": " The Source Control Management used (currently only 'git' is supported)",
            "help": " Show this help page",
            "dependency": " Project dependencies. Pattern should be a semicolon-separated AppName@Branch@Build list. May be specified more than once.",
            "dependenciesFile": " A path to a json file that is in the following format: [{\"appName\":\"\",\"branch\":\"\",\"build\":\"\"},{...}]",
            "recursive": "Starts a recursive search for JARs & WARs in folder specified by the 'workspacepath' option",
            "author": "Optional. The name or email of the user that should be associated with this build. May be specified more than once.",
            "logsUrl": "Optional. The logs url of the build.",
            "jobName": "Optional. The jenkins job name that triggered the build.",
            "usebranchcoverage": "Optional. Include branches in scan",
        },

        defaults = {
            "help": "",
        };

    var buildArguments = nopt(knownOpts, shortHands, process.argv, 2);
    ["branch", "build", "appname"].forEach(function (key) {
        if (!buildArguments[key]) {
            console.error("Required argument '" + key + "' not specified");
            hasMissingArguments = true;
        }
    });

    var hadInvalidArguments = false;

    //workspacepath, scm must all come together or not at all
    var count = 0;
    ["workspacepath", "scm"].forEach(function (key) {
        if (buildArguments[key]) {
            count++;
        }
    });

    if (count != 0 && count != 2) {
        console.error("The 'workspacepath' and 'scm' command-line arguments must be specified together or not at all");
        hadInvalidArguments = true;
    }

    var parsedDependencies = [];
    if (buildArguments.dependency && !hadInvalidArguments) {
        try {
            parsedDependencies = parseDependencies(buildArguments.dependency);
        }
        catch (e) {
            console.error(e);
            hadInvalidArguments = true;
        }
    }
    
    if (buildArguments.dependenciesFile && !hadInvalidArguments) {
        try {
            var parsedJson = readJsonSync(buildArguments.dependenciesFile);
            if (!parsedJson || !Array.isArray(parsedJson)) {
                throw 'Invalid file structure';
            }
            
            parsedJson.forEach(function (depItem) {
                if (depItem.appName && depItem.build && depItem.branch) {
                    parsedDependencies.push({ appName: depItem.appName.toString(), branch: depItem.branch.toString(), build: depItem.build.toString() });
                } else {
                    throw 'Invalid dependency item: ' + JSON.stringify(depItem);
                }
            });

        } catch (e) {
            console.error('Error reading/parsing ' + buildArguments.dependenciesFile + ": " + e);
            hadInvalidArguments = true;
        }
    }
    
    if (hasMissingArguments || hadInvalidArguments || buildArguments.help) {
        try {
            var usage = noptUsage(knownOpts, shortHands, description, defaults);
            console.error(usage);
        } catch (e) {
            console.error(e);
        }
        callback(1);
        return;
    }

    var sourceConrolProviders = this.getSourceConrolProviders();
    var cfg = cfgLoader(buildArguments.config).then(function (cfg) {
        var diffService = new NewDiffService(cfg, needle);
            var buildDiffProcess = new BuildDiffProcess(cfg, diffService, sourceConrolProviders, parsedDependencies);
            buildDiffProcess.run(buildArguments).then(function () {
                callback(0);
        }).catch(function (err) {
            callback(1);
            });
    });
}

module.exports.CIA = CIA;
